This is the mail archive of the cygwin-apps mailing list for the Cygwin project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[PATCH setup 3/3] Remove references to "last-extrakeys"


Extra gpg keys used to be stored in a file /etc/setup/last-extrakeys.
These keys are now saved in the "extrakeys" user setting, but there
were still references to "last-extrakeys" in comments and in a help
string.
---
 KeysSetting.h | 2 +-
 crypto.cc     | 8 ++++----
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/KeysSetting.h b/KeysSetting.h
index 9cd0f9a..f7b9336 100644
--- a/KeysSetting.h
+++ b/KeysSetting.h
@@ -34,7 +34,7 @@ class ExtraKeysSetting
     size_t numkeys;
     static ExtraKeysSetting *global;
   public:
-    // Loads keys from last-extrakeys
+    // Loads keys from the "extrakeys" user setting.
     ExtraKeysSetting ();
     // Saves them back again.
     ~ExtraKeysSetting ();
diff --git a/crypto.cc b/crypto.cc
index a606283..5a10e16 100644
--- a/crypto.cc
+++ b/crypto.cc
@@ -48,7 +48,7 @@ static StringArrayOption SexprExtraKeyOption ('S', "sexpr-pubkey",
 			"Extra public key in s-expr format");
 
 static BoolOption UntrustedKeysOption (false, 'u', "untrusted-keys",
-			"Use untrusted keys from last-extrakeys");
+			"Use untrusted saved extra keys");
 static BoolOption KeepUntrustedKeysOption (false, 'U', "keep-untrusted-keys",
 			"Use untrusted keys and retain all");
 
@@ -466,9 +466,9 @@ verify_ini_file_sig (io_stream *ini_file, io_stream *ini_sig_file, HWND owner)
   msg ("key:%d\n'%s'", n, sexprbuf);
 #endif /* CRYPTODEBUGGING */
 
-  /* Next we should extract the keys from the last-extrakeys
-  file, and flush it; we'll only return them to it if they
-  get used.  OTOH, should we do this at all?  The extrakeys
+  /* Next we should extract the keys from the extrakeys user
+  setting, and flush it; we'll only return them to it if they
+  get used.  OTOH, should we do this at all?  The user settings
   file isn't heavily protected.  So we only trust the extra
   keys if we're told to by the user.  We still read them in
   and write them back out, which canonicalises and eliminates
-- 
2.15.0


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]